@@ -250,7 +250,7 @@ EAProperty.share(
     contact=EAProperty(),
     contactMethodPreferenceCode=EAProperty('contact_preference_code', 'preference_code', 'contact_preference'),
     contactMode=EAProperty(),
-    contactModeId=EAProperty('contact_mode'),
+    contactModeId=EAProperty(),
     contactTypeId=EAProperty('contact_type'),
     contentId=EAProperty('content'),
     contributionCount=EAProperty('contributions'),
@@ -388,6 +388,7 @@ EAProperty.share(
     isConfirmedOptInEnabled=EAProperty('confirmed_opt_in_enabled', 'opt_in_enabled', 'opt_in'),
     isCoreField=EAProperty('is_core', 'core_field', 'core'),
     isCustomDistrict=EAProperty('custom_district', 'is_custom', 'custom'),
+    isDeceased=EAProperty('deceased'),
     isEditable=EAProperty('editable'),
     isEventLead=EAProperty('event_lead', 'lead'),
     isExportable=EAProperty('exportable'),
@@ -486,6 +487,7 @@ EAProperty.share(
     parentId=EAProperty('parent'),
     parentOrganization=EAProperty('parent', factory=_employer_factory),
     parentValueId=EAProperty('parent_value'),
+    partialDateOfBirth=EAProperty('partial_birthday'),
     party=EAProperty(),
     paymentType=EAProperty(),
     personIdColumn=EAProperty('id_column', 'id_col'),
@@ -519,6 +521,8 @@ EAProperty.share(
     resourceTypes=EAProperty('resources', singular_alias='resource'),
     resourceUrl=EAProperty('url'),
     responseId=EAProperty('response'),
+    restrictToRelationshipContactMode=EAProperty('restrict_to_mode'),
+    restrictToReverseRelationshipContactMode=EAProperty('restrict_to_reverse_mode'),
     result=EAProperty(),
     resultCodeId=EAProperty('result_code'),
     resultFileColumnName=EAProperty('result_column_name', 'result_column', 'column_name', 'column'),
@@ -665,8 +669,8 @@ class Attribution(EAObject, _shared={'amountAttributed', 'attributionType', 'dat
 
 class AvailableValue(EAObject, _id='id', _name='name', _shared={'parentValueId'}):
     """Represents
-    `AvailableValues <https://docs.everyaction.com/reference/custom-fields-common-models#available-value>`__
-    for a Custom Field.
+    `AvailableValues <https://docs.everyaction.com/reference/custom-fields-common-models#available-value>`__ for a
+    Custom Field.
     """
 
 
@@ -695,7 +699,9 @@ class BankAccount(EAObject, _id='id', _name='name', _prefix='bankAccount'):
 class BargainingUnit(
     EAObject, _id='id', _name='name', _prefix='bargainingUnit', _shared={'employerBargainingUnitId', 'shortName'}
 ):
-    """Represents a `Bargaining Unit <https://docs.everyaction.com/reference/common-models-3#bargaining-unit>`__."""
+    """Represents a `Bargaining Unit
+    <https://docs.everyaction.com/reference/bargaining-units-common-models#bargaining-unit>`__.
+    """
 
 
 class Canvasser(EAObject, _id='id', _prefix='canvasser'):
@@ -748,8 +754,7 @@ class ChangeType(
 
 class CodeResult(EAObject, _id='id', _prefix='code', _shared={'message'}):
     """Represents the data associated with a response to a code batch request. See `POST /codes/batch
-    <https://docs.everyaction.com/reference/codes-batch>`__
-    for an example.
+    <https://docs.everyaction.com/reference/codes-batch>`__ for an example.
     """
 
 
@@ -776,7 +781,7 @@ class Commitment(
         'status'
     }
 ):
-    """Represents a `Commitment <https://docs.everyaction.com/reference/common-models-6#commitment>`__."""
+    """Represents a `Commitment <https://docs.everyaction.com/reference/commitments-common-models#commitment>`__."""
 
 
 class ConfirmationEmailData(
@@ -797,7 +802,7 @@ class ConfirmationEmailData(
 
 
 class ContactType(EAObject, _id='id', _name='name', _prefix='contactType', _shared={'channelTypeName'}):
-    """Represents a `Contact Type <https://docs.everyaction.com/reference/canvassresponsescontacttypes>`__."""
+    """Represents a `Contact Type <https://docs.everyaction.com/reference/canvassresponses-contacttypes>`__."""
 
 
 class Constraints(EAObject, _shared={'invalidCharacters', 'maxLength'}):
@@ -842,11 +847,11 @@ class CustomFieldValue(EAObject, _shared={'assignedValue', 'customFieldGroupId',
 
 
 class Department(EAObject, _id='id', _name='name', _prefix='department', _shared={'employer', 'parentDepartmentId'}):
-    """Represents a `Department <https://docs.everyaction.com/reference/common-models-10#department>`__."""
+    """Represents a `Department <https://docs.everyaction.com/reference/departments-common-models#department>`__."""
 
 
 class Designation(EAObject, _id='id', _name='name', _prefix='designation'):
-    """Represents a `Designation <https://docs.everyaction.com/reference/common-models-11#designation>`__."""
+    """Represents a `Designation <https://docs.everyaction.com/reference/designations-common-models#designation>`__."""
 
 
 class DisclosureFieldValue(
@@ -937,9 +942,7 @@ class EmployerPhone(
 
 
 class EventRole(EAObject, _id='id', _name='name', _prefix='role', _shared={'goal', 'isEventLead', 'max', 'min'}):
-    """Represents a `Role <https://docs.everyaction.com/reference/common-models-18#role>`__
-    for an Event Type.
-    """
+    """Represents a `Role <https://docs.everyaction.com/reference/common-models-18#role>`__ for an Event Type."""
 
 
 class EventShift(EAObject, _id='id', _name='name', _prefix='eventShift', _shared={'endTime', 'startTime'}):
@@ -951,8 +954,8 @@ class ExportJobType(EAObject, _id='id', _name='name', _prefix='exportJobType'):
 
 
 class File(EAObject, _shared={'dateExpired', 'downloadUrl', 'recordCount'}):
-    """Represents a `File object <https://docs.everyaction.com/reference/targetexportjobsexportjobid#file>`__
-    in EveryAction. Used in many contexts.
+    """Represents a `File object <https://docs.everyaction.com/reference/targetexportjobsexportjobid#file>`__ in
+    EveryAction. Used in many contexts.
     """
 
 
@@ -1022,13 +1025,13 @@ class JobClass(EAObject, _id='id', _name='name', _prefix='jobClass', _shared={'s
 
 
 class JobNotification(EAObject, _shared={'description', 'message', 'status'}):
-    """Represents a `Notification <https://docs.everyaction.com/reference/fileloadingjobs#notification>`__
-    for File Loading Jobs.
+    """Represents a `Notification <https://docs.everyaction.com/reference/fileloadingjobs#notification>`__ for File
+    Loading Jobs.
     """
 
 
 class InputType(EAObject, _id='id', _name='name', _prefix='inputType'):
-    """Represents an `Input Type <https://docs.everyaction.com/reference/canvassresponsesinputtypes>`__."""
+    """Represents an `Input Type <https://docs.everyaction.com/reference/canvassresponses-inputtypes>`__."""
 
 
 class KeyValuePair(EAObject, _shared={'key', 'value'}):
@@ -1038,14 +1041,12 @@ class KeyValuePair(EAObject, _shared={'key', 'value'}):
 
 
 class Listener(EAObject, _shared={'type', 'value'}):
-    """Represents a `Listener <https://docs.everyaction.com/reference/fileloadingjobs>`__
-    for a file-loading job.
-    """
+    """Represents a `Listener <https://docs.everyaction.com/reference/fileloadingjobs>`__ for a file-loading job."""
 
 
 class MappingValue(EAObject, _id='id', _name='name', _shared={'parentId', 'sourceValue', 'targetValue'}):
-    """Represents a `value <https://docs.everyaction.com/reference/bulkimportjobs#mapping-types>`__
-    in the context of bulk import jobs.
+    """Represents a `value <https://docs.everyaction.com/reference/bulkimportjobs#mapping-types>`__ in the context of
+    bulk import jobs.
     """
 
 
@@ -1095,7 +1096,12 @@ class RelationalMapping(EAObject, _shared={'fieldName', 'value'}):
     """
 
 
-class Relationship(EAObject, _id='id', _name='name'):
+class Relationship(
+    EAObject,
+    _id='id',
+    _name='name',
+    _shared={'restrictToRelationshipContactMode', 'restrictToReverseRelationshipContactMode'}
+):
     """Represents a `Relationship <https://docs.everyaction.com/reference/relationships-1>`__."""
 
 
@@ -1130,7 +1136,7 @@ class ReportedSexualOrientation(
 class ResultCode(
     EAObject, _id='id', _name='name', _prefix='resultCode', _shared={'mediumName', 'resultOutcomeGroup', 'shortName'}
 ):
-    """Represents a `Result Code <https://docs.everyaction.com/reference/canvassresponsesresultcodes>`__."""
+    """Represents a `Result Code <https://docs.everyaction.com/reference/canvassresponses-resultcodes>`__."""
 
 
 class SavedList(
@@ -1145,8 +1151,8 @@ class SavedListData(
     _prefix='savedList',
     _shared={'matchedRowsCount', 'originalRowCount', 'unmatchedRowsCount'}
 ):
-    """Represents `Saved List Data <https://docs.everyaction.com/reference/fileloadingjobs#saved-list-load>`__
-    for Saved List Load actions.
+    """Represents `Saved List Data <https://docs.everyaction.com/reference/fileloadingjobs#saved-list-load>`__ for Saved
+    List Load actions.
     """
 
 
@@ -1194,8 +1200,8 @@ class ShiftType(EAObject, _id='id', _name='name', _prefix='shiftType', _shared={
 
 
 class Status(EAObject, _id='id', _name='name', _prefix='status'):
-    """Represents a `Status <https://docs.everyaction.com/reference/common-models-17>`__
-    in EveryAction. Used in multiple contexts.
+    """Represents a `Status <https://docs.everyaction.com/reference/common-models-17>`__ in EveryAction. Used in
+    multiple contexts.
     """
 
 
@@ -1204,9 +1210,7 @@ class StoryStatus(EAObject, _id='id', _name='statusName', _prefix='storyStatus')
 
 
 class Subgroup(EAObject, _id='id', _name='name', _prefix='subgroup', _shared={'fullName', 'isAssociatedWithBadges'}):
-    """Represents a `Subgroup <https://docs.everyaction.com/reference/common-models-37#subgroup>`__
-    for a Target.
-    """
+    """Represents a `Subgroup <https://docs.everyaction.com/reference/common-models-37#subgroup>`__ for a Target."""
 
 
 class SupportedEntity(EAObject, _name='name', _shared={'isApplicable', 'isSearchable'}):
@@ -1239,10 +1243,10 @@ class Suppression(EAObject, _name='name', _prefix='suppression', _prefixed={'cod
         code_or_name: Optional[str] = None,
         **kwargs: EAValue
     ) -> None:
-        """
-        Initialize by setting the specified property names and aliases. Note that values will automatically be converted
-        to API objects when appropriate. When the positional argument `code_or_name` is given, it is assumed to be a
-        code (e.g., "NC" for "Do not call") when it has length at most 2, and otherwise it is assumed to be a name.
+        """Initialize by setting the specified property names and aliases. Note that values will automatically be
+        converted to API objects when appropriate. When the positional argument `code_or_name` is given, it is assumed
+        to be a code (e.g., "NC" for "Do not call") when it has length at most 2, and otherwise it is assumed to be a
+        name.
 
         :param code_or_name: When the given, it is assumed to be a code (e.g., "NC" for "Do not call") when it has
             length at most 2, and otherwise it is assumed to be a name.
@@ -1275,7 +1279,7 @@ class Suppression(EAObject, _name='name', _prefix='suppression', _prefixed={'cod
     def no_call(self) -> bool:
         """Indicates whether this is a "Do Not Call" suppression.
 
-        :returns: :code:`True` if this is a "Do Not Call" suppression, :code:`False` otherwise.
+        :return: ``True`` if this is a "Do Not Call" suppression, ``False`` otherwise.
         """
         return (self.code or '').upper() == 'NC' or (self.name or '').lower() == 'do not call'
 
@@ -1283,7 +1287,7 @@ class Suppression(EAObject, _name='name', _prefix='suppression', _prefixed={'cod
     def no_email(self) -> bool:
         """Indicates whether this is a "Do Not Email" suppression.
 
-        :returns: :code:`True` if this is a "Do Not Email" suppression, :code:`False` otherwise.
+        :return: ``True`` if this is a "Do Not Email" suppression, ``False`` otherwise.
         """
         return (self.code or '').upper() == 'NE' or (self.name or '').lower() == 'do not email'
 
@@ -1291,7 +1295,7 @@ class Suppression(EAObject, _name='name', _prefix='suppression', _prefixed={'cod
     def no_mail(self) -> bool:
         """Indicates whether this is a "Do Not Mail" suppression.
 
-        :returns: :code:`True` if this is a "Do Not Mail" suppression, :code:`False` otherwise.
+        :return: ``True`` if this is a "Do Not Mail" suppression, ``False`` otherwise.
         """
         return (self.code or '').upper() == 'NM' or (self.name or '').lower() == 'do not mail'
 
@@ -1299,7 +1303,7 @@ class Suppression(EAObject, _name='name', _prefix='suppression', _prefixed={'cod
     def no_walk(self) -> bool:
         """Indicate whether this is a "Do Not Walk" suppression.
 
-        :returns: :code:`True` if this is a "Do Not Walk" suppression, :code:`False` otherwise.
+        :return: ``True`` if this is a "Do Not Walk" suppression, ``False`` otherwise.
         """
         return (self.code or '').upper() == 'NW' or (self.name or '').lower() == 'do not walk'
 
@@ -1311,14 +1315,10 @@ Suppression.DO_NOT_WALK = Suppression('NW')
 
 
 class SurveyResponse(EAObject, _id='id', _name='name', _prefix='surveyResponse', _shared={'mediumName', 'shortName'}):
-    """
-    Represents a `Survey Response <https://docs.everyaction.com/reference/common-models-36#survey-response>`__.
-    """
+    """Represents a `Survey Response <https://docs.everyaction.com/reference/common-models-36#survey-response>`__."""
 
 
-class UpdateStatistics(
-    EAObject
-):
+class UpdateStatistics(EAObject):
     """Represents an `Update Statistics <https://docs.everyaction.com/reference/score-updates>`__ object."""
 
 
@@ -1582,8 +1582,8 @@ class JobFile(
 
 
 class ListLoadCallbackData(JobNotification, _shared={'description', 'message', 'savedList', 'status'}):
-    """Represents `Callback Data <https://docs.everyaction.com/reference/fileloadingjobs#callback-data>`__
-    for a Saved List Load action.
+    """Represents `Callback Data <https://docs.everyaction.com/reference/fileloadingjobs#callback-data>`__ for a Saved
+    List Load action.
     """
 
 
@@ -1614,8 +1614,8 @@ class Membership(
         'totalDuesPaid'
     }
 ):
-    """Contains `membership information <https://docs.everyaction.com/reference/people-vanid-membership>`__
-    for a person.
+    """Contains `membership information <https://docs.everyaction.com/reference/people-vanid-membership>`__ for a
+    person.
     """
 
 
@@ -1772,8 +1772,8 @@ class SupportField(
     _shared={'customPropertyKey', 'displayName', 'fieldType', 'maxFieldLength', 'possibleValues'}
 ):
     """Represents a `Support Field
-    <https://docs.everyaction.com/reference/voterregistrationbatchesstatesstatesupportedfields>`__
-    for a Voter Registration Batch.
+    <https://docs.everyaction.com/reference/voterregistrationbatchesstatesstatesupportedfields>`__ for a Voter
+    Registration Batch.
     """
 
 
@@ -1781,8 +1781,8 @@ class SurveyCanvassResponse(
     ScriptResponse,
     _shared={'mediumName', 'name', 'shortName', 'surveyQuestionId', 'surveyResponseId'}
 ):
-    """Represents a `Survey Response <https://docs.everyaction.com/reference/people-vanid-canvassresponses>`__
-    in the context of a canvass response.
+    """Represents a `Survey Response <https://docs.everyaction.com/reference/people-vanid-canvassresponses>`__ in the
+    context of a canvass response.
     """
 
     def __init__(
@@ -1894,8 +1894,7 @@ EAProperty.share(
 
 class AddRegistrantsResponse(EAObject, _shared={'alternateId', 'errors', 'result', 'vanId'}):
     """Represents the data associated with a response to `adding registrants
-    <https://docs.everyaction.com/reference/voterregistrationbatchesbatchidpeople>`__
-    to a Voter Registration Batch.
+    <https://docs.everyaction.com/reference/voterregistrationbatchesbatchidpeople>`__ to a Voter Registration Batch.
     """
 
 
@@ -1966,20 +1965,20 @@ class ChangedEntityField(
         +------------+--------------------------------------------------------------------------------------------+
         | Field Type | Behavior                                                                                   |
         +============+============================================================================================+
-        | B          | Parses "true" to :code:`True` and "false" to :code:`False`.                                |
+        | B          | Parses "true" to ``True`` and "false" to ``False``.                                        |
         +------------+--------------------------------------------------------------------------------------------+
         | D          | Parses into a naive `datetime object <https://docs.python.org/3/library/datetime.html>`__. |
         +------------+--------------------------------------------------------------------------------------------+
         | M          | Keeps the original string value.                                                           |
         +------------+--------------------------------------------------------------------------------------------+
-        | N          | Parses into an :code:`int`.                                                                |
+        | N          | Parses into an ``int``.                                                                    |
         +------------+--------------------------------------------------------------------------------------------+
         | T          | Keeps the original string value.                                                           |
         +------------+--------------------------------------------------------------------------------------------+
 
 
         :param value: The value to parse.
-        :returns: The parsed value.
+        :return: The parsed value.
         """
         return self._TYPE_TO_FACTORY[self.type](value) if value else None
 
@@ -2125,6 +2124,7 @@ class Person(
         'formalEnvelopeName',
         'formalSalutation',
         'identifiers',
+        'isDeceased',
         'jobTitle',
         'lastName',
         'middleName',
@@ -2133,6 +2133,7 @@ class Person(
         'organizationContactCommonName',
         'organizationContactOfficialName',
         'organizationRoles',
+        'partialDateOfBirth',
         'party',
         'phones',
         'pronouns',
@@ -2158,15 +2159,6 @@ class Person(
 ):
     """Represents a `Person <https://docs.everyaction.com/reference/common-models#match-candidate>`__."""
 
-    @staticmethod
-    def _find_factory(**kwargs: EAValue) -> Optional['Person']:
-        status = kwargs.get('status')
-        if status is not None:
-            if status != 'Unmatched':
-                raise AssertionError(f'Only expected Unmatched status, found "{status}"')
-            return None
-        return Person(**kwargs)
-
     @staticmethod
     def _get_preferred(of: List[Any], attr: Optional[str] = None) -> Optional[Any]:
         # Get a preferred entity from a list of entities by checking the "preferred" attribute.
@@ -2184,7 +2176,7 @@ class Person(
         """Adds the given suppression to this person if it is not already present.
 
         :param suppression: The suppression to add.
-        :returns: :code:`True` if the suppression was added, :code:`False` if it was already present.
+        :return: ``True`` if the suppression was added, ``False`` if it was already present.
         """
         # noinspection PyAttributeOutsideInit
         self.suppressions = self.suppressions or []
@@ -2197,9 +2189,9 @@ class Person(
         """Determines whether this contact has the given suppression.
 
         :param suppression: The suppression to check for.
-        :returns: :code:`True` if this contact has the suppression, :code:`False` if suppression information is
-            available (when :code:`suppressions` attribute is not :code:`None`) and the suppression was not found, or
-            :code:`None` if no suppression information is available.
+        :return: ``True`` if this contact has the suppression, ``False`` if suppression information is available (when
+            *suppressions* attribute is not ``None``) and the suppression was not found, or ``None`` if no suppression
+            information is available.
         """
         if self.suppressions is not None:
             return suppression in self.suppressions
@@ -2209,7 +2201,7 @@ class Person(
         """Removes the given suppression from this person if it is present.
 
         :param suppression: The suppression to remove.
-        :returns: :code:`True` if the suppression was removed, :code:`False` if the suppression was not found.
+        :return: ``True`` if the suppression was removed, ``False`` if the suppression was not found.
         """
         if self.suppressions:
             try:
@@ -2223,8 +2215,8 @@ class Person(
         """Add or remove the given suppression.
 
         :param suppression: Suppression to add or remove.
-        :param value: :code:`True` to add the suppression, :code:`False` to remove it.
-        :returns: :code:`True` if suppressions were changed, :code:`False` otherwise.
+        :param value: ``True`` to add the suppression, ``False`` to remove it.
+        :return: ``True`` if suppressions were changed, ``False`` otherwise.
         """
         if value:
             return self.add_suppression(suppression)
@@ -2235,8 +2227,8 @@ class Person(
     def do_not_call(self) -> Optional[bool]:
         """Determine if this contact is marked as "Do Not Call".
 
-        :returns: :code:`True` is this contact is marked as "Do Not Call", :code:`False` is suppressions are present
-            and do not contain "Do Not Call", or :code:`None` if no suppression information is available.
+        :return: ``True`` is this contact is marked as "Do Not Call", ``False`` is suppressions are present and do not
+            contain "Do Not Call", or ``None`` if no suppression information is available.
         """
         return self.has_suppression(Suppression.DO_NOT_CALL)
 
@@ -2252,8 +2244,8 @@ class Person(
     def do_not_email(self) -> Optional[bool]:
         """Determine if this contact is marked as "Do Not Email".
 
-        :returns: :code:`True` is this contact is marked as "Do Not Email", :code:`False` is suppressions are present
-            and do not contain "Do Not Email", or :code:`None` if no suppression information is available.
+        :return: ``True`` is this contact is marked as "Do Not Email", ``False`` is suppressions are present and do not
+            contain "Do Not Email", or ``None`` if no suppression information is available.
         """
         return self.has_suppression(Suppression.DO_NOT_EMAIL)
 
@@ -2269,8 +2261,8 @@ class Person(
     def do_not_mail(self) -> Optional[bool]:
         """Determine if this contact is marked as "Do Not Mail".
 
-        :returns: :code:`True` is this contact is marked as "Do Not Mail", :code:`False` is suppressions are present
-            and do not contain "Do Not Mail", or :code:`None` if no suppression information is available.
+        :return: ``True`` is this contact is marked as "Do Not Mail", ``False`` is suppressions are present and do not
+            contain "Do Not Mail", or ``None`` if no suppression information is available.
         """
         return self.has_suppression(Suppression.DO_NOT_MAIL)
 
@@ -2286,8 +2278,8 @@ class Person(
     def do_not_walk(self) -> Optional[bool]:
         """Determine if this contact is marked as "Do Not Mail".
 
-        :returns: :code:`True` is this contact is marked as "Do Not Walk", :code:`False` is suppressions are present
-            and do not contain "Do Not Walk", or :code:`None` if no suppression information is available.
+        :return: ``True`` is this contact is marked as "Do Not Walk", ``False`` is suppressions are present and do not
+            contain "Do Not Walk", or ``None`` if no suppression information is available.
         """
         return self.has_suppression(Suppression.DO_NOT_WALK)
 
@@ -2301,29 +2293,28 @@ class Person(
 
     @property
     def preferred_address(self) -> Optional[Address]:
-        """Get this contact's preferred mailing address as an :class:`.Address` object if it exists, or :code:`None`
-        if this contact has no addresses or if information on what address is preferred is unavailable.
+        """Get this contact's preferred mailing address as an :class:`.Address` object if it exists, or ``None`` if this
+        contact has no addresses or if information on what address is preferred is unavailable.
 
-        :returns: The preferred mailing address object, or :code:`None` if no preferred mailing address could be
-            determined.
+        :return: The preferred mailing address object, or ``None`` if no preferred mailing address could be determined.
         """
         return self._get_preferred(self.addresses)
 
     @property
     def preferred_email(self) -> Optional[str]:
-        """Get the address of this contact's preferred email if it exists, or :code:`None` if this contact has no email
+        """Get the address of this contact's preferred email if it exists, or ``None`` if this contact has no email
         addresses or if information on what address is preferred is unavailable.
 
-        :returns: The preferred email address, or code:`None` if no preferred email address could be determined.
+        :return: The preferred email address, or code:`None` if no preferred email address could be determined.
         """
         return self._get_preferred(self.emails, "email")
 
     @property
     def preferred_phone(self) -> Optional[str]:
-        """Get the number of this contact's preferred phone if it exists, or :code:`None` if this contact has no phone
+        """Get the number of this contact's preferred phone if it exists, or ``None`` if this contact has no phone
         numbers or if information on what number is preferred is unavailable.
 
-        :returns: The preferred phone number, or code:`None` if no preferred phone number could be determined.
+        :return: The preferred phone number, or code:`None` if no preferred phone number could be determined.
         """
         return self._get_preferred(self.phones, "number")
 
@@ -2351,8 +2342,8 @@ class SurveyQuestion(
 
 class ValueMappingData(EAObject, _id='id', _name='name', _shared={'parents'}):
     """Represents data for an existing `value mapping
-    <https://docs.everyaction.com/reference/bulkimportmappingtypes-mappingtypename-fieldname-values>`__
-    in the context of bulk import jobs.
+    <https://docs.everyaction.com/reference/bulkimportmappingtypes-mappingtypename-fieldname-values>`__ in the context
+    of bulk import jobs.
     """
 
 
@@ -2464,8 +2455,8 @@ class MappingTypeData(EAObject, _name='name', _shared={'allowMultipleMode', 'dis
 
 
 class Registrant(EAObject, _shared={'alternateId', 'customProperties', 'person'}):
-    """Represents a `Registrant <https://docs.everyaction.com/reference/voterregistrationbatchesbatchidpeople>`__
-    for a Voter Registration Batch.
+    """Represents a `Registrant <https://docs.everyaction.com/reference/voterregistrationbatchesbatchidpeople>`__ for a
+    Voter Registration Batch.
     """
 
 
